Properties Methods Events Config Options Direct Link

# Class Ext.ux.ProgressBarPager

Package: | Ext.ux
Defined In: | ux-all-debug.js
Class: | ProgressBarPager
Extends: | Object

Plugin (ptype = 'tabclosemenu') for displaying a progressbar inside of a paging toolbar instead of plain text

## Config Options

Config Options | Defined By
--- | ---
| defaultAnimCfg : Object A Ext.Fx configuration object. Default is { duration : 1, easing : 'bounceOut' }. | ProgressBarPager
| defaultAnimCfg : Object A Ext.Fx configuration object. Default is { duration : 1, easing : 'bounceOut' }. | ProgressBarPager
| defaultText : String The text to display while the store is loading. Default is 'Loading...' | ProgressBarPager
| defaultText : String The text to display while the store is loading. Default is 'Loading...' | ProgressBarPager
| progBarWidth : Integer The default progress bar width. Default is 225. | ProgressBarPager
| progBarWidth : Integer The default progress bar width. Default is 225. | ProgressBarPager

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.